@@ -15,7 +15,7 @@ has 'password';
 has 'proxy';
 has 'ua' => sub { Mojo::UserAgent->new; };
 
-our $VERSION = '1.2.13.0';
+our $VERSION = '1.2.13.1';
 
 
 sub _execute {
@@ -40,8 +40,9 @@ sub _execute {
 
     $args->{args}->{apikey} = $c->apikey;
 
-    my $tx = $c->ua->get($url => form => $args->{args});
-    if (my $res = $tx->success) {
+    my $tx  = $c->ua->get($url => form => $args->{args});
+    my $res = $tx->result;
+    if ($res->is_success) {
         my $json = $res->json;
         if ($json->{code} == 0) {
             return 1 if $args->{boolean};
@@ -59,7 +60,7 @@ sub _execute {
             return undef;
         }
     } else {
-        carp Dumper $tx->error;
+        carp Dumper $res->message;
         return undef;
     }
 }
@@ -725,6 +726,41 @@ sub create_diff_html {
 }
 
 
+#################### subroutine header begin ####################
+
+
+#################### subroutine header end ####################
+
+
+sub restore_revision {
+    my $c      = shift;
+    my $pad_id = shift;
+    my $rev    = shift;
+
+    unless (defined($pad_id)) {
+        carp 'Please provide a pad id, a start_rev and an end_rev';
+        return undef;
+    }
+
+    unless (defined($rev)) {
+        carp 'Please provide a revision number';
+        return undef;
+    }
+
+    my $args = {
+        padID => $pad_id,
+        rev   => $rev
+    };
+
+    return $c->_execute({
+        api     => '1.2.11',
+        method  => 'restoreRevision',
+        boolean => 1,
+        args    => $args
+    });
+}
+
+
 #################################################################
 #################################################################
 
@@ -1504,7 +1540,7 @@ Etherpad - interact with Etherpad API
 
 =head1 VERSION
 
-version 1.2.13.0
+version 1.2.13.1
 
 =head1 SYNOPSIS
 
@@ -1788,7 +1824,7 @@ See L<http://etherpad.org/doc/v1.6.0/#index_pad_content>
 
 =head3 create_diff_html
 
- Usage     : $ec->create_diff_html
+ Usage     : $ec->create_diff_html('padId', rev1, rev2)
  Purpose   : Returns an object of diffs from 2 points in a pad
  Returns   : A hash reference which keys are
              * html, which content is a string representing the diff between the two revisions
@@ -1796,6 +1832,14 @@ See L<http://etherpad.org/doc/v1.6.0/#index_pad_content>
  Argument  : Takes a pad ID, a revision number to start and a revision number to end. All arguments are mandatory
  See       : http://etherpad.org/doc/v1.6.0/#index_creatediffhtml_padid_startrev_endrev
 
+=head3 restore_revision
+
+ Usage     : $ec->restore_revision('padId', rev)
+ Purpose   : Restores revision from past as new changeset
+ Returns   : 1 if it succeeds
+ Argument  : Takes a pad ID, a revision number to restore. All arguments are mandatory
+ See       : http://etherpad.org/doc/v1.7.0/#index_restorerevision_padid_rev
+
 =head2 Chat
 
 See L<http://etherpad.org/doc/v1.6.0/#index_chat>
@@ -2044,12 +2088,12 @@ You can find documentation for this module with the perldoc command.
 
 Bugs and feature requests will be tracked on:
 
-    https://framagit.org/luc/etherpad/issues
+    https://framagit.org/fiat-tux/etherpad/issues
 
 The latest source code can be browsed and fetched at:
 
-    https://framagit.org/luc/etherpad
-    git clone https://framagit.org/luc/etherpad.git
+    https://framagit.org/fiat-tux/etherpad
+    git clone https://framagit.org/fiat-tux/etherpad.git
 
 Source code mirror:
 
